@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/config_f.h,v 3.12 1995/03/05 03:18:09 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/config_f.h,v 3.13 1996/04/26 19:17:30 christos Exp $ */
 /*
  * config_f.h -- configure various defines for tcsh
  *
@@ -104,7 +104,7 @@
  *		on the name of the tty, and environment.
  *		Does not make sense in the modern window systems!
  */
-#undef AUTOLOGOUT
+#define AUTOLOGOUT
 
 /*
  * SUSPENDED	Newer shells say 'Suspended' instead of 'Stopped'.
@@ -129,12 +129,11 @@
  *		This can be much slower and no memory statistics will be
  *		provided.
  */
-/* #if defined(PURIFY) || defined(MALLOC_TRACE) */
-#define SYSMALLOC
-/* #else
- * # undef SYSMALLOC
- * #endif
- */
+#if defined(PURIFY) || defined(MALLOC_TRACE)
+# define SYSMALLOC
+#else
+# undef SYSMALLOC
+#endif
 
 /*
  * REMOTEHOST	Try to determine the remote host that we logged in from
