@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/ed.chared.c,v 3.46 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/ed.chared.c,v 3.48 1996/10/19 17:53:49 christos Exp $ */
 /*
  * ed.chared.c: Character editing functions.
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: ed.chared.c,v 3.46 1995/04/16 19:15:53 christos Exp $")
+RCSID("$Id: ed.chared.c,v 3.48 1996/10/19 17:53:49 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -571,6 +571,7 @@ excl_sw:
 			xfree((ptr_t) omodbuf);
 		    omodbuf = modbuf;
 		}
+		++q;
 		break;
 
 	    case 'a':
@@ -578,16 +579,23 @@ excl_sw:
 		/* Not implemented; this needs to be done before expanding
 		 * lex. We don't have the words available to us anymore.
 		 */
+		++q;
 		break;
 
 	    case 'p':
 		/* Ok */
+		++q;
+		break;
+
+	    case '\0':
 		break;
 
 	    default:
+		++q;
 		break;
 	    }
-	    q += 2;
+	    if (q[1])
+		++q;
 	}
 	if (omodbuf != buf) {
 	    (void) Strcpy(buf, omodbuf);
@@ -803,7 +811,7 @@ c_get_histline()
 	CurrentHistLit = 1;
     }
     else {
-	(void) sprlex(InputBuf, &hp->Hlex);
+	(void) sprlex(InputBuf, sizeof(InputBuf), &hp->Hlex);
 	CurrentHistLit = 0;
     }
     LastChar = InputBuf + Strlen(InputBuf);
@@ -1220,6 +1228,10 @@ e_insert(c)
 #ifndef SHORT_STRINGS
     c &= ASCII;			/* no meta chars ever */
 #endif
+#ifdef DSPKANJI
+    CCRETVAL ret;
+    ret = (CCRETVAL)CC_NORM;
+#endif
 
     if (!c)
 	return(CC_ERROR);	/* no NULs in the input ever!! */
@@ -1261,7 +1273,11 @@ e_insert(c)
     if (inputmode == MODE_REPLACE_1)
 	(void) v_cmd_mode(0);
 
+#ifdef DSPKANJI
+    return(ret);
+#else
     return(CC_NORM);
+#endif
 }
 
 int
@@ -1481,7 +1497,7 @@ e_toggle_hist(c)
 	}
     }
     else {
-	(void) sprlex(InputBuf, &hp->Hlex);
+	(void) sprlex(InputBuf, sizeof(InputBuf), &hp->Hlex);
 	CurrentHistLit = 0;
     }
 
@@ -1607,7 +1623,7 @@ e_up_search_hist(c)
     *LastChar = '\0';		/* just in case */
     if (Hist_num < 0) {
 #ifdef DEBUG_EDIT
-	xprintf("tcsh: e_up_search_hist(): Hist_num < 0; resetting.\n");
+	xprintf("%s: e_up_search_hist(): Hist_num < 0; resetting.\n", progname);
 #endif
 	Hist_num = 0;
 	return(CC_ERROR);
@@ -1632,9 +1648,9 @@ e_up_search_hist(c)
     while (hp != NULL) {
 	Char sbuf[INBUFSIZE], *hl;
 	if (hp->histline == NULL) {
-	    hp->histline = Strsave(sprlex(sbuf, &hp->Hlex));
+	    hp->histline = Strsave(sprlex(sbuf, sizeof(sbuf), &hp->Hlex));
 	}
-	hl = HistLit ? hp->histline : sprlex(sbuf, &hp->Hlex);
+	hl = HistLit ? hp->histline : sprlex(sbuf, sizeof(sbuf), &hp->Hlex);
 #ifdef SDEBUG
 	xprintf("Comparing with \"%S\"\n", hl);
 #endif
@@ -1685,9 +1701,9 @@ e_down_search_hist(c)
     for (h = 1; h < Hist_num && hp; h++) {
 	Char sbuf[INBUFSIZE], *hl;
 	if (hp->histline == NULL) {
-	    hp->histline = Strsave(sprlex(sbuf, &hp->Hlex));
+	    hp->histline = Strsave(sprlex(sbuf, sizeof(sbuf), &hp->Hlex));
 	}
-	hl = HistLit ? hp->histline : sprlex(sbuf, &hp->Hlex);
+	hl = HistLit ? hp->histline : sprlex(sbuf, sizeof(sbuf), &hp->Hlex);
 #ifdef SDEBUG
 	xprintf("Comparing with \"%S\"\n", hl);
 #endif
