@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/ed.term.h,v 1.11 1994/09/04 21:54:15 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/ed.term.h,v 1.13 1996/09/24 16:57:20 christos Exp $ */
 /*
  * ed.term.h: Local terminal header
  */
@@ -451,6 +451,16 @@
 # endif /* NUMCC */
 #endif /* !POSIX */
 
+/*
+ * fix for hpux10 inconsistency: it has VWERASE, but TIOCSLTC returns
+ * EINVAL if one tries to change it
+ */
+#if defined(hpux) && defined(VSUSP) && defined(VDSUSP) && defined(VWERASE) && d
+efined(VLNEXT)
+# undef TIOCGLTC       /* not really needed */
+# undef TIOCSLTC
+#endif
+
 #define C_INTR		 0
 #define C_QUIT		 1
 #define C_ERASE		 2
