@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/pathnames.h,v 3.15 1995/01/20 23:48:56 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/pathnames.h,v 3.16 1996/04/26 19:18:42 christos Exp $ */
 /*
  * pathnames.h: Location of things to find
  */
@@ -141,7 +141,7 @@
 #endif /* !_PATH_CSHELL */
 
 #ifndef _PATH_TCSHELL
-#  define _PATH_TCSHELL		"/usr/bin/tcsh"
+#  define _PATH_TCSHELL		"/usr/local/bin/tcsh"
 #endif /* !_PATH_TCSHELL */
 
 #ifndef _PATH_BIN_LOGIN
