@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.dir.c,v 3.40 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.dir.c,v 3.42 1996/06/22 21:44:28 christos Exp $ */
 /*
  * sh.dir.c: Directory manipulation functions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.dir.c,v 3.40 1995/04/16 19:15:53 christos Exp $")
+RCSID("$Id: sh.dir.c,v 3.42 1996/06/22 21:44:28 christos Exp $")
 
 /*
  * C Shell - directory management
@@ -62,7 +62,7 @@ static void
 dstart(from)
     const char *from;
 {
-    xprintf(CGETS(12, 1, "tcsh: Trying to start from \"%s\"\n"), from);
+    xprintf(CGETS(12, 1, "%s: Trying to start from \"%s\"\n"), progname, from);
 }
 
 /*
@@ -80,7 +80,7 @@ dinit(hp)
     /* Don't believe the login shell home, because it may be a symlink */
     tcp = (char *) getwd(path);
     if (tcp == NULL || *tcp == '\0') {
-	xprintf("tcsh: %s\n", path);
+	xprintf("%s: %s\n", progname, path);
 	if (hp && *hp) {
 	    tcp = short2str(hp);
 	    dstart(tcp);
@@ -137,7 +137,7 @@ dinit(hp)
     dp->di_next = dp->di_prev = &dhead;
     printd = 0;
     dnewcwd(dp, 0);
-    set(STRdirstack, Strsave(dp->di_name), VAR_READWRITE);
+    set(STRdirstack, Strsave(dp->di_name), VAR_READWRITE|VAR_NOGLOB);
 }
 
 static void
@@ -148,8 +148,8 @@ Char *dp;
      * Don't call set() directly cause if the directory contains ` or
      * other junk characters glob will fail. 
      */
-    set(STRowd, Strsave(varval(STRcwd)), VAR_READWRITE);
-    set(STRcwd, Strsave(dp), VAR_READWRITE);
+    set(STRowd, Strsave(varval(STRcwd)), VAR_READWRITE|VAR_NOGLOB);
+    set(STRcwd, Strsave(dp), VAR_READWRITE|VAR_NOGLOB);
 
     tsetenv(STRPWD, dp);
 }
@@ -1345,10 +1345,10 @@ recdirs(fname, def)
 
 	if (cdflag == 0) {
 	    cdflag = 1;
-	    xprintf("cd %S\n", dp->di_name);
+	    xprintf("cd '%S'\n", dp->di_name);
 	}
 	else
-	    xprintf("pushd %S\n", dp->di_name);
+	    xprintf("pushd '%S'\n", dp->di_name);
 
 	if (num-- == 0)
 	    break;
