@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.err.c,v 3.26 1995/03/12 04:49:26 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.err.c,v 3.28 1996/10/19 17:54:46 christos Exp $ */
 /*
  * sh.err.c: Error printing routines. 
  */
@@ -37,7 +37,7 @@
 #define _h_sh_err		/* Don't redefine the errors	 */
 #include "sh.h"
 
-RCSID("$Id: sh.err.c,v 3.26 1995/03/12 04:49:26 christos Exp $")
+RCSID("$Id: sh.err.c,v 3.28 1996/10/19 17:54:46 christos Exp $")
 
 /*
  * C Shell
@@ -270,7 +270,7 @@ errinit()
     elst[ERR_JOBPAT] = CSAVS(1, 61, "No job matches pattern");
     elst[ERR_NESTING] = CSAVS(1, 62, "Fork nesting > %d; maybe `...` loop");
     elst[ERR_JOBCTRLSUB] = CSAVS(1, 63, "No job control in subshells");
-    elst[ERR_SYNC] = CSAVS(1, 64, "Sunc fault: Process %d not found");
+    elst[ERR_SYNC] = CSAVS(1, 64, "Sync fault: Process %d not found");
     elst[ERR_STOPPED] =
 #ifdef SUSPENDED
 	CSAVS(1, 65, "%sThere are suspended jobs");
@@ -335,20 +335,20 @@ errinit()
     elst[ERR_TCNARGS] = CSAVS(1, 120, "`%s' requires %d arguments");
     elst[ERR_TCUSAGE] = CSAVS(1, 121,
 	"Usage: echotc [-v|-s] [<capability> [<args>]]");
-    elst[ERR_ARCH] = CSAVS(1, 122, "%s: %s. Wrong Architecture");
+    elst[ERR_ARCH] = CSAVS(1, 122, "%s: %s. Binary file not executable");
     elst[ERR_HISTLOOP] = CSAVS(1, 123, "!# History loop");
     elst[ERR_FILEINQ] = CSAVS(1, 124, "Malformed file inquiry");
     elst[ERR_SELOVFL] = CSAVS(1, 125, "Selector overflow");
 #ifdef apollo
     elst[ERR_TCSHUSAGE] = CSAVS(1, 126,
-"Unknown option: `-%s'\nUsage: tcsh [ -bcdefilmnqstvVxX -Dname[=value] ] [ argument ... ]");
+"Unknown option: `-%s'\nUsage: %s [ -bcdefilmnqstvVxX -Dname[=value] ] [ argument ... ]");
 #else /* !apollo */
 # ifdef convex
     elst[ERR_TCSHUSAGE] = CSAVS(1, 127,
-"Unknown option: `-%s'\nUsage: tcsh [ -bcdefFilmnqstvVxX ] [ argument ... ]");
+"Unknown option: `-%s'\nUsage: %s [ -bcdefFilmnqstvVxX ] [ argument ... ]");
 # else /* rest */
     elst[ERR_TCSHUSAGE] = CSAVS(1, 128,
-"Unknown option: `-%s'\nUsage: tcsh [ -bcdefilmnqstvVxX ] [ argument ... ]");
+"Unknown option: `-%s'\nUsage: %s [ -bcdefilmnqstvVxX ] [ argument ... ]");
 # endif /* convex */
 #endif /* apollo */
     elst[ERR_COMPCOM] = CSAVS(1, 129, "\nInvalid completion: \"%s\"");
