@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.exec.c,v 3.34 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.exec.c,v 3.37 1996/10/05 17:39:08 christos Exp $ */
 /*
  * sh.exec.c: Search, find, and execute a command!
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.exec.c,v 3.34 1995/04/16 19:15:53 christos Exp $")
+RCSID("$Id: sh.exec.c,v 3.37 1996/10/05 17:39:08 christos Exp $")
 
 #include "tc.h"
 #include "tw.h"
@@ -185,7 +185,7 @@ doexec(t)
 #endif /* VFORK */
 
     v = adrof(STRpath);
-    if (v == 0 && expath[0] != '/') {
+    if (v == 0 && expath[0] != '/' && expath[0] != '.') {
 	blkfree(pv);
 	pexerr();
     }
@@ -433,7 +433,8 @@ texec(sf, st)
 	 * it, don't feed it to the shell if it looks like a binary!
 	 */
 	if ((fd = open(f, O_RDONLY)) != -1) {
-	    if (read(fd, (char *) pref, 2) == 2) {
+	    int nread;
+	    if ((nread = read(fd, (char *) pref, 2)) == 2) {
 		if (!Isprint(pref[0]) && (pref[0] != '\n' && pref[0] != '\t')) {
 		    (void) close(fd);
 		    /*
@@ -442,6 +443,12 @@ texec(sf, st)
 		    stderror(ERR_ARCH, f, strerror(errno));
 		}
 	    }
+	    else if (nread < 0 && errno != EINTR) {
+#ifdef convex
+		/* need to print error incase the file is migrated */
+		stderror(ERR_SYSTEM, CMDname, strerror(errno));
+#endif
+	    }
 #ifdef _PATH_BSHELL
 	    else {
 		pref[0] = '#';
@@ -893,7 +900,7 @@ tellmewhat(lexp, str)
     register int i;
     register struct biltins *bptr;
     register struct wordent *sp = lexp->next;
-    bool    aliased = 0;
+    bool    aliased = 0, found;
     Char   *s0, *s1, *s2, *cmd;
     Char    qc;
 
@@ -969,18 +976,18 @@ tellmewhat(lexp, str)
 	    }
 	    else
 		prlex(lexp);
-	    sp->word = s0;	/* we save and then restore this */
-	    xfree((ptr_t) cmd);
-	    return TRUE;
 	}
-	s1 = Strspl(*pv, STRslash);
-	sp->word = Strspl(s1, sp->word);
-	xfree((ptr_t) s1);
-	if (str == NULL)
-	    prlex(lexp);
-	else
-	    (void) Strcpy(str, sp->word);
-	xfree((ptr_t) sp->word);
+	else {
+	    s1 = Strspl(*pv, STRslash);
+	    sp->word = Strspl(s1, sp->word);
+	    xfree((ptr_t) s1);
+	    if (str == NULL)
+		prlex(lexp);
+	    else
+		(void) Strcpy(str, sp->word);
+	    xfree((ptr_t) sp->word);
+	}
+	found = 1;
     }
     else {
 	if (str == NULL) {
@@ -989,14 +996,13 @@ tellmewhat(lexp, str)
 	    xprintf(CGETS(13, 6, "%S: Command not found.\n"), sp->word);
 	    flush();
 	}
-	else {
+	else
 	    (void) Strcpy(str, sp->word);
-	    return FALSE;
-	}
+	found = 0;
     }
     sp->word = s0;		/* we save and then restore this */
     xfree((ptr_t) cmd);
-    return TRUE;
+    return found;
 }
 
 /*
