@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.file.c,v 3.12 1995/04/29 22:28:24 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.file.c,v 3.14 1996/06/22 21:44:34 christos Exp $ */
 /*
  * sh.file.c: File completion for csh. This file is not used in tcsh.
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.file.c,v 3.12 1995/04/29 22:28:24 christos Exp $")
+RCSID("$Id: sh.file.c,v 3.14 1996/06/22 21:44:34 christos Exp $")
 
 #ifdef FILEC
 
@@ -815,7 +815,7 @@ tenex(inputline, inputline_size)
 	if (command == LIST)	/* Always retype after a LIST */
 	    should_retype = TRUE;
 	if (should_retype)
-	    printprompt();
+	    printprompt(0, NULL);
 	pushback(inputline);
 	if (should_retype)
 	    retype();
