@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.func.c,v 3.64 1995/05/06 17:51:58 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.func.c,v 3.66 1996/10/05 17:39:10 christos Exp $ */
 /*
  * sh.func.c: csh builtin functions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.func.c,v 3.64 1995/05/06 17:51:58 christos Exp $")
+RCSID("$Id: sh.func.c,v 3.66 1996/10/05 17:39:10 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -56,7 +56,6 @@ extern bool GotTermCaps;
 static int zlast = -1;
 
 static	void	islogin		__P((void));
-static	void	reexecute	__P((struct command *));
 static	void	preread		__P((void));
 static	void	doagain		__P((void));
 static  char   *isrchx		__P((int));
@@ -104,7 +103,7 @@ isbfunc(t)
      * one past the end.
      */
     for (bp1 = bfunc, bp2 = bfunc + nbfunc; bp1 < bp2;) {
-	register i;
+	int i;
 
 	bp = bp1 + ((bp2 - bp1) >> 1);
 	if ((i = *cp - *bp->bname) == 0 &&
@@ -417,7 +416,7 @@ doif(v, kp)
  * Reexecute a command, being careful not
  * to redo i/o redirection, which is already set up.
  */
-static void
+void
 reexecute(kp)
     register struct command *kp;
 {
@@ -760,10 +759,10 @@ doswbrk(v, c)
 
 int
 srchx(cp)
-    register Char *cp;
+    Char *cp;
 {
-    register struct srch *sp, *sp1, *sp2;
-    register i;
+    struct srch *sp, *sp1, *sp2;
+    int i;
 
     /*
      * Ignore keywords inside heredocs
@@ -1349,7 +1348,14 @@ dosetenv(v, c)
     }
 
     if (eq(vp, STRKTERM)) {
+	char *t;
 	set(STRterm, quote(lp), VAR_READWRITE);	/* lp memory used here */
+	t = short2str(lp);
+	if (noediting && strcmp(t, "unknown") != 0 && strcmp(t,"dumb") != 0) {
+	    editing = 1;
+	    noediting = 0;
+	    set(STRedit, Strsave(STRNULL), VAR_READWRITE);
+	}
 	GotTermCaps = 0;
 	ed_Init();
 	return;
@@ -1560,7 +1566,7 @@ Unsetenv(name)
 {
     register Char **ep = STR_environ;
     register Char *cp, *dp;
-    Char  **oep = ep;
+    Char **oep = ep;
 
     for (; *ep; ep++) {
 	for (cp = name, dp = *ep; *cp && *cp == *dp; cp++, dp++)
@@ -1570,6 +1576,7 @@ Unsetenv(name)
 	cp = *ep;
 	*ep = 0;
 	STR_environ = blkspl(STR_environ, ep + 1);
+	blkfree((Char **) environ);
 	environ = short2blk(STR_environ);
 	*ep = cp;
 	xfree((ptr_t) cp);
@@ -1606,7 +1613,7 @@ doumask(v, c)
 # ifndef BSDLIMIT
    typedef long RLIM_TYPE;
 #  ifndef RLIM_INFINITY
-#   if !defined(_MINIX) && !defined(__clipper__)
+#   if !defined(_MINIX) && !defined(__clipper__) && !defined(_CRAY)
     extern RLIM_TYPE ulimit();
 #   endif /* ! _MINIX && !__clipper__ */
 #   define RLIM_INFINITY 0x003fffff
@@ -2094,7 +2101,7 @@ retry:
 /* This is the dreaded EVAL built-in.
  *   If you don't fiddle with file descriptors, and reset didfds,
  *   this command will either ignore redirection inside or outside
- *   its aguments, e.g. eval "date >x"  vs.  eval "date" >x
+ *   its arguments, e.g. eval "date >x"  vs.  eval "date" >x
  *   The stuff here seems to work, but I did it by trial and error rather
  *   than really knowing what was going on.  If tpgrp is zero, we are
  *   probably a background eval, e.g. "eval date &", and we want to
