@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.h,v 3.68 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.h,v 3.73 1996/10/19 17:54:12 christos Exp $ */
 /*
  * sh.h: Catch it all globals and includes file!
  */
@@ -191,7 +191,13 @@ typedef int sigret_t;
 # if SYSVREL>3 && !defined(sgi) && !defined(sun) && !(defined(__alpha) && defined(__osf__))
 #  include "/usr/ucbinclude/sys/resource.h"
 # else
-#  include <sys/resource.h>
+#  ifdef convex
+#   define sysrusage cvxrusage
+#   include <sys/sysinfo.h>
+#  else
+#   define sysrusage rusage
+#   include <sys/resource.h>
+#  endif /* convex */
 # endif /* SYSVREL>3 */
 #endif /* BSDTIMES */
 
@@ -199,7 +205,7 @@ typedef int sigret_t;
 # ifdef TERMIO
 #  include <termio.h>
 # else /* SGTTY */
-#  include <bsd/sgtty.h>
+#  include <sgtty.h>
 # endif /* TERMIO */
 #else /* POSIX */
 # include <termios.h>
@@ -261,7 +267,10 @@ extern pid_t setpgrp();
 # endif /* !pyr && !stellar */
 #endif /* SYSVREL > 0 ||  _IBMR2 */
 
-#if !((defined(SUNOS4) || defined(_MINIX) || defined(DECOSF1)) && defined(TERMIO))
+/* In the following ifdef the DECOSF1 has been commented so that later
+ * versions of DECOSF1 will get TIOCGWINSZ. This might break older versions...
+ */
+#if !((defined(SUNOS4) || defined(_MINIX) /* || defined(DECOSF1) */) && defined(TERMIO))
 # if !defined(COHERENT) && !defined(_VMS_POSIX)
 #  include <sys/ioctl.h>
 # endif
@@ -493,12 +502,14 @@ EXTERN bool    setintr;		/* Set interrupts on/off -> Wait intr... */
 EXTERN bool    timflg;		/* Time the next waited for command */
 EXTERN bool    havhash;		/* path hashing is available */
 EXTERN bool    editing;		/* doing filename expansion and line editing */
+EXTERN bool    noediting;	/* initial $term defaulted to noedit */
 EXTERN bool    bslash_quote;	/* PWP: tcsh-style quoting?  (in sh.c) */
 EXTERN bool    isoutatty;	/* is SHOUT a tty */
 EXTERN bool    isdiagatty;	/* is SHDIAG a tty */
 EXTERN bool    is1atty;		/* is file descriptor 1 a tty (didfds mode) */
 EXTERN bool    is2atty;		/* is file descriptor 2 a tty (didfds mode) */
 EXTERN bool    arun;		/* Currently running multi-line-aliases */
+EXTERN int     implicit_cd;	/* implicit cd enabled? (1=enabled,2=verbose) */
 EXTERN bool    inheredoc;	/* Currently parsing a heredoc */
 
 /*
@@ -515,7 +526,7 @@ EXTERN Char   *shtemp;		/* Temp name for << shell files in /tmp */
 
 #ifdef BSDTIMES
 EXTERN struct timeval time0;	/* Time at which the shell started */
-EXTERN struct rusage ru0;
+EXTERN struct sysrusage ru0;
 #else
 # ifdef _SEQUENT_
 EXTERN timeval_t time0;		/* time at which shell started */
@@ -883,6 +894,7 @@ EXTERN struct varent {
 #define VAR_ALL		-1
 #define VAR_READONLY	1
 #define VAR_READWRITE	2
+#define VAR_NOGLOB	4
     struct varent *v_link[3];	/* The links, see below */
     int     v_bal;		/* Balance factor */
 }       shvhed, aliases;
@@ -987,7 +999,7 @@ EXTERN Char    PRCHROOT;	/* Prompt symbol for root */
  */
 #ifndef SHORT_STRINGS
 #define Strchr(a, b)  		strchr(a, b)
-#define Strrchr(a, b)  	strrchr(a, b)
+#define Strrchr(a, b)  		strrchr(a, b)
 #define Strcat(a, b)  		strcat(a, b)
 #define Strncat(a, b, c) 	strncat(a, b, c)
 #define Strcpy(a, b)  		strcpy(a, b)
@@ -1064,22 +1076,32 @@ extern int     dont_free;	/* Tell free that we are in danger if we free */
 extern Char    *INVPTR;
 extern Char    **INVPPTR;
 
+extern char    *progname;
+extern int	tcsh;
+
 #include "tc.h"
 #include "sh.decls.h"
 
 /*
  * To print system call errors...
  */
-#ifndef linux
-#ifdef NEEDstrerror
+#ifdef __NetBSD__
+# include <errno.h>
+#else
+# ifndef linux
+#  ifdef NEEDstrerror
 extern char *sys_errlist[];
-#endif
+#  endif
 extern int errno, sys_nerr;
-#endif /* !linux */
+# endif /* !linux */
+#endif
 
 #ifdef NLS_CATALOGS
 # ifdef linux
-/* #  include <localeinfo.h> */
+#  include <locale.h>
+#  ifdef notdef
+#   include <localeinfo.h>	/* Has this changed ? */
+#  endif
 #  include <features.h>
 # endif
 # ifdef SUNOS4
@@ -1105,4 +1127,11 @@ EXTERN nl_catd catd;
 # define CSAVS(b, c, d)	d
 #endif 
 
+/*
+ * Since on some machines characters are unsigned, and the signed
+ * keyword is not universally implemented, we treat all characters
+ * as unsigned and sign extend them where we need.
+ */
+#define SIGN_EXTEND_CHAR(a)	(((a) & 0x80) ? ((a) | ~0x7f) : (a))
+
 #endif /* _h_sh */
