@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.hist.c,v 3.20 1994/07/08 14:43:50 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.hist.c,v 3.23 1996/10/27 16:58:57 christos Exp $ */
 /*
  * sh.hist.c: Shell history expansions and substitutions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.hist.c,v 3.20 1994/07/08 14:43:50 christos Exp $")
+RCSID("$Id: sh.hist.c,v 3.23 1996/10/27 16:58:57 christos Exp $")
 
 #include "tc.h"
 
@@ -54,6 +54,7 @@ static	void	phist	__P((struct Hist *, int));
 #define HIST_REV	0x08
 #define HIST_CLEAR	0x10
 #define HIST_MERGE	0x20
+#define HIST_TIME	0x40
 
 /*
  * C shell
@@ -131,19 +132,25 @@ enthist(event, lp, docopy, mflg)
 	    for (p = pp; (px = p, p = p->Hnext) != NULL;)
 		if (heq(lp, &(p->Hlex))){
 		    px->Hnext = p->Hnext;
+		    n = p->Hnum + 1;
 		    hfree(p);
-		    p = NULL;
+		    for (p = px->Hnext; p != NULL; p = p->Hnext)
+			p->Href = n--;
 		    break;
 		}
 	}
 	else if (eq(dp, STRall)) {
 	    for (p = pp; (p = p->Hnext) != NULL;)
-		if (heq(lp, &(p->Hlex)))
+		if (heq(lp, &(p->Hlex))) {
+		    eventno--;
 		    break;
+		}
 	}
 	else if (eq(dp, STRprev)) {
-	    if (pp->Hnext && heq(lp, &(pp->Hnext->Hlex)))
+	    if (pp->Hnext && heq(lp, &(pp->Hnext->Hlex))) {
 		p = pp->Hnext;
+		eventno--;
+	    }
 	}
     }
 
@@ -254,8 +261,11 @@ dohist(vp, c)
 	    case 'M':
 	    	hflg |= HIST_MERGE;
 		break;
+	    case 'T':
+	    	hflg |= HIST_TIME;
+		break;
 	    default:
-		stderror(ERR_HISTUS, "chrSLM");
+		stderror(ERR_HISTUS, "chrSLMT");
 		break;
 	    }
     }
@@ -308,18 +318,28 @@ phist(hp, hflg)
     register struct Hist *hp;
     int     hflg;
 {
-
+    extern bool output_raw;
     if (hflg & HIST_ONLY) {
-	/* 
-	 * Make file entry with history time in format:
-	 * "+NNNNNNNNNN" (10 digits, left padded with ascii '0') 
-	 */
-	xprintf("#+%010lu\n", hp->Htime);
+       /*
+        * Control characters have to be written as is (output_raw).
+        * This way one can preserve special characters (like tab) in
+        * the history file.
+        * From: mveksler@vnet.ibm.com (Veksler Michael)
+        */
+        output_raw= 1;
+	if (hflg & HIST_TIME)
+	    /* 
+	     * Make file entry with history time in format:
+	     * "+NNNNNNNNNN" (10 digits, left padded with ascii '0') 
+	     */
+
+	    xprintf("#+%010lu\n", hp->Htime);
 
 	if (HistLit && hp->histline)
 	    xprintf("%S\n", hp->histline);
 	else
 	    prlex(&hp->Hlex);
+        output_raw= 0;
     }
     else {
 	Char   *cp = str2short("%h\t%T\t%R\n");
@@ -353,7 +373,7 @@ fmthist(fmt, ptr, buf)
 	else {
 	    Char ibuf[INBUFSIZE], *ip;
 	    char *p;
-	    (void) sprlex(ibuf, &hp->Hlex);
+	    (void) sprlex(ibuf, sizeof(ibuf), &hp->Hlex);
 	    for (p = buf, ip = ibuf; (*p++ = *ip++) != '\0'; )
 		continue;
 	}
@@ -373,7 +393,7 @@ rechist(fname, ref)
     Char    *snum;
     int     fp, ftmp, oldidfds;
     struct varent *shist;
-    static Char   *dumphist[] = {STRhistory, STRmh, 0, 0};
+    static Char   *dumphist[] = {STRhistory, STRmhT, 0, 0};
 
     if (fname == NULL && !ref) 
 	return;
