@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.lex.c,v 3.43 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.lex.c,v 3.46 1996/10/05 17:39:12 christos Exp $ */
 /*
  * sh.lex.c: Lexical analysis into tokens
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.lex.c,v 3.43 1995/04/16 19:15:53 christos Exp $")
+RCSID("$Id: sh.lex.c,v 3.46 1996/10/05 17:39:12 christos Exp $")
 
 #include "ed.h"
 /* #define DEBUG_INP */
@@ -140,6 +140,12 @@ static Char getCtmp;
 time_t Htime = (time_t)0;
 static time_t a2time_t __P((Char *));
 
+/*
+ * for history event processing
+ * in the command 'echo !?foo?:1 !$' we want the !$ to expand from the line
+ * 'foo' was found instead of the last command
+ */
+static int uselastevent = 1;
 
 int
 lex(hp)
@@ -149,6 +155,7 @@ lex(hp)
     int     c;
 
 
+    uselastevent = 1;
     histvalid = 0;
     histlinep = histline;
     *histlinep = '\0';
@@ -573,10 +580,11 @@ getdol()
 		seterror(ERR_VARILL);
 	    else {
 		ungetD(c);
-		*--np = 0;
-		addla(name);
-		return;
+		--np;
 	    }
+	    *np = 0;
+	    addla(name);
+	    return;
 	}
 	if (toolong) {
 	    seterror(ERR_VARTOOLONG);
@@ -741,7 +749,12 @@ getexcl(sc)
 	}
     }
     quesarg = -1;
-    lastev = eventno;
+
+    if (uselastevent) {
+	uselastevent = 0;
+	lastev = eventno;
+    }
+	lastev = eventno;
     hp = gethent(sc);
     if (hp == 0)
 	return;
@@ -1308,7 +1321,7 @@ gethent(sc)
 	    }
 	    np = lhsb;
 	    event = 0;
-	    while (!cmap(c, _ESC | _META | _QF | _QB) && !any("${}:#", c)) {
+	    while (!cmap(c, _ESC | _META | _QF | _QB) && !any("^*-%${}:#", c)) {
 		if (event != -1 && Isdigit(c))
 		    event = event * 10 + c - '0';
 		else
@@ -1455,9 +1468,9 @@ readc(wanteof)
     bool    wanteof;
 {
     int c;
-    static  sincereal;	/* Number of real EOFs we've seen */
-    Char *ptr;		/* For STRignoreeof */
-    int numeof = 0;	/* Value of STRignoreeof */
+    static  int sincereal;	/* Number of real EOFs we've seen */
+    Char *ptr;			/* For STRignoreeof */
+    int numeof = 0;		/* Value of STRignoreeof */
 
 #ifdef DEBUG_INP
     xprintf("readc\n");
@@ -1627,7 +1640,8 @@ reread:
 					"\nUse \"logout\" to logout.\n"));
 		   	} else {
 				xprintf(CGETS(16, 3,
-					"\nUse \"exit\" to leave tcsh.\n"));
+					"\nUse \"exit\" to leave %s.\n"),
+					progname);
 			}
 			reset();
 		} else {
@@ -1686,6 +1700,10 @@ bgetc()
 	    do
 		c = read(SHIN, tbuf, BUFSIZE);
 	    while (c < 0 && errno == EINTR);
+#ifdef convex
+	    if (c < 0)
+		stderror(ERR_SYSTEM, progname, strerror(errno));
+#endif /* convex */
 	    if (c <= 0)
 		return (-1);
 	    for (i = 0; i < c; i++)
