@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.proc.h,v 3.6 1993/10/30 19:50:16 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.proc.h,v 3.7 1996/04/26 19:20:17 christos Exp $ */
 /*
  * sh.proc.h: Process data structures and variables
  */
@@ -61,7 +61,7 @@ struct process {
 #ifdef BSDTIMES
     struct timeval p_btime;	/* begin time */
     struct timeval p_etime;	/* end time */
-    struct rusage p_rusage;
+    struct sysrusage p_rusage;
 #else				/* BSDTIMES */
 # ifdef _SEQUENT_
     timeval_t p_btime;		/* begin time */
