@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.sem.c,v 3.36 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.sem.c,v 3.39 1996/09/24 16:57:25 christos Exp $ */
 /*
  * sh.sem.c: I/O redirections and job forking. A touchy issue!
  *	     Most stuff with builtins is incorrect
@@ -37,9 +37,10 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.sem.c,v 3.36 1995/04/16 19:15:53 christos Exp $")
+RCSID("$Id: sh.sem.c,v 3.39 1996/09/24 16:57:25 christos Exp $")
 
 #include "tc.h"
+#include "tw.h"
 
 #ifdef CLOSE_ON_EXEC
 # ifndef SUNOS4
@@ -122,6 +123,53 @@ execute(t, wanttty, pipein, pipeout)
     if (t == 0) 
 	return;
 
+    /*
+     * Ed hutchins@sgi.com & Dominic dbg@sgi.com
+     * Sat Feb 25 03:13:11 PST 1995
+     * try implicit cd if we have a 1 word command 
+     */
+    if (implicit_cd && (intty || intact) && t->t_dcom && t->t_dcom[0] &&
+	 t->t_dcom[0][0] && (blklen(t->t_dcom) == 1) && !noexec) {
+	Char sCName[MAXPATHLEN];
+	Char *pCN;
+	struct stat stbuf;
+
+	dollar(sCName, t->t_dcom[0]);
+	pCN = sCName;
+	if (pCN[0] == '~') {
+	    Char sCPath[MAXPATHLEN];
+	    Char *pCP = sCPath;
+
+	    ++pCN;
+	    while (*pCN && *pCN != '/')
+		*pCP++ = *pCN++;
+	    *pCP = 0;
+	    if (sCPath[0])
+		gethdir(sCPath);
+	    else
+		(void) Strcpy(sCPath, varval(STRhome));
+	    catn(sCPath, pCN, MAXPATHLEN);
+	    (void) Strcpy(sCName, sCPath);
+	}
+    
+	/* if this is a dir, tack a "cd" on as the first arg */
+	if (stat(short2str(sCName), &stbuf) != -1) {
+	    if (S_ISDIR(stbuf.st_mode)) {
+		Char *vCD[2];
+		Char **ot_dcom = t->t_dcom;
+	    
+		vCD[0] = Strsave(STRcd);
+		vCD[1] = NULL;
+		t->t_dcom = blkspl(vCD, ot_dcom);
+		if (implicit_cd > 1) {
+		    blkpr(t->t_dcom);
+		    xputchar( '\n' );
+		}
+		xfree((ptr_t) ot_dcom);
+	    }
+	}
+    }
+
     VOL_SAVE();
     _gv.forked = 0;
     _gv.wanttty = wanttty;
@@ -508,12 +556,14 @@ execute(t, wanttty, pipein, pipeout)
 			(void) signal(SIGHUP, SIG_IGN);
 		    if (t->t_dflg & F_HUP)
 			(void) signal(SIGHUP, SIG_DFL);
-		    if (t->t_dflg & F_NICE)
+		    if (t->t_dflg & F_NICE) {
+			int nval = SIGN_EXTEND_CHAR(t->t_nice);
 # ifdef BSDNICE
-			(void) setpriority(PRIO_PROCESS, 0, t->t_nice);
+			(void) setpriority(PRIO_PROCESS, 0, nval);
 # else /* !BSDNICE */
-			(void) nice(t->t_nice);
+			(void) nice(nval);
 # endif /* BSDNICE */
+		    }
 # ifdef F_VER
 		    if (t->t_dflg & F_VER) {
 			tsetenv(STRSYSTYPE, t->t_systype ? STRbsd43 : STRsys53);
@@ -789,6 +839,10 @@ doio(t, pipein, pipeout)
 	    xfree((ptr_t) cp);
 	    if ((fd = open(tmp, O_RDONLY)) < 0)
 		stderror(ERR_SYSTEM, tmp, strerror(errno));
+#ifdef O_LARGEFILE
+	    /* allow input files larger than 2Gb  */
+	    (void) fcntl(fd, O_LARGEFILE, 0);
+#endif /* O_LARGEFILE */
 	    (void) dmove(fd, 0);
 	}
 	else if (flags & F_PIPEIN) {
@@ -832,7 +886,7 @@ doio(t, pipein, pipeout)
 	    fd = open(tmp, O_WRONLY | O_APPEND);
 #else /* !O_APPEND */
 	    fd = open(tmp, O_WRONLY);
-	    (void) lseek(1, (off_t) 0, L_XTND);
+	    (void) lseek(fd, (off_t) 0, L_XTND);
 #endif /* O_APPEND */
 	}
 	else
@@ -845,6 +899,10 @@ doio(t, pipein, pipeout)
 	    }
 	    if ((fd = creat(tmp, 0666)) < 0)
 		stderror(ERR_SYSTEM, tmp, strerror(errno));
+#ifdef O_LARGEFILE
+	    /* allow input files larger than 2Gb  */
+	    (void) fcntl(fd, O_LARGEFILE, 0);
+#endif /* O_LARGEFILE */
 	}
 	(void) dmove(fd, 1);
 	is1atty = isatty(1);
