@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/sh.set.c,v 3.28 1995/03/12 04:49:26 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.set.c,v 3.31 1996/10/05 17:39:14 christos Exp $ */
 /*
  * sh.set.c: Setting and Clearing of variables
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.set.c,v 3.28 1995/03/12 04:49:26 christos Exp $")
+RCSID("$Id: sh.set.c,v 3.31 1996/10/05 17:39:14 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -109,16 +109,20 @@ update_vars(vp)
 	    symlinks = 0;
     }
     else if (eq(vp, STRterm)) {
-#ifdef DOESNT_WORK_RIGHT
-	register Char *cp;
-#endif /* DOESNT_WORK_RIGHT */
-	tsetenv(STRKTERM, varval(vp));
+	Char *cp = varval(vp);
+	tsetenv(STRKTERM, cp);
 #ifdef DOESNT_WORK_RIGHT
 	cp = getenv("TERMCAP");
 	if (cp && (*cp != '/'))	/* if TERMCAP and not a path */
 	    Unsetenv(STRTERMCAP);
 #endif /* DOESNT_WORK_RIGHT */
 	GotTermCaps = 0;
+	if (noediting && Strcmp(cp, STRnetwork) != 0 &&
+	    Strcmp(cp, STRunknown) != 0 && Strcmp(cp, STRdumb) != 0) {
+	    editing = 1;
+	    noediting = 0;
+	    set(STRedit, Strsave(STRNULL), VAR_READWRITE);
+	}
 	ed_Init();		/* reset the editor */
     }
     else if (eq(vp, STRhome)) {
@@ -141,6 +145,7 @@ update_vars(vp)
     }
     else if (eq(vp, STRedit)) {
 	editing = 1;
+	noediting = 0;
 	/* PWP: add more stuff in here later */
     }
     else if (eq(vp, STRshlvl)) {
@@ -160,6 +165,9 @@ update_vars(vp)
 	resetwatch();
     }
 #endif /* HAVENOUTMP */
+    else if (eq(vp, STRimplicitcd)) {
+	implicit_cd = ((eq(varval(vp), STRverbose)) ? 2 : 1);
+    }
 }
 
 
@@ -524,7 +532,7 @@ adrof1(name, v)
     register Char *name;
     register struct varent *v;
 {
-    register cmp;
+    int cmp;
 
     v = v->v_left;
     while (v && ((cmp = *name - *v->v_name) != 0 || 
@@ -559,17 +567,19 @@ set1(var, vec, head, flags)
 {
     register Char **oldv = vec;
 
-    gflag = 0;
-    tglob(oldv);
-    if (gflag) {
-	vec = globall(oldv);
-	if (vec == 0) {
+    if ((flags & VAR_NOGLOB) == 0) {
+	gflag = 0;
+	tglob(oldv);
+	if (gflag) {
+	    vec = globall(oldv);
+	    if (vec == 0) {
+		blkfree(oldv);
+		stderror(ERR_NAME | ERR_NOMATCH);
+		return;
+	    }
 	    blkfree(oldv);
-	    stderror(ERR_NAME | ERR_NOMATCH);
-	    return;
+	    gargv = 0;
 	}
-	blkfree(oldv);
-	gargv = 0;
     }
     setq(var, vec, head, flags);
 }
@@ -582,7 +592,7 @@ setq(name, vec, p, flags)
     int flags;
 {
     register struct varent *c;
-    register f;
+    register int f;
 
     f = 0;			/* tree hangs off the header's left link */
     while ((c = p->v_link[f]) != 0) {
@@ -614,10 +624,11 @@ unset(v, c)
     Char   **v;
     struct command *c;
 {
-    bool did_only;
+    bool did_roe, did_edit;
 
     USE(c);
-    did_only = adrof(STRrecognize_only_executables) != NULL;
+    did_roe = adrof(STRrecognize_only_executables) != NULL;
+    did_edit = adrof(STRedit) != NULL;
     unset1(v, &shvhed);
     if (adrof(STRhistchars) == 0) {
 	HIST = '!';
@@ -639,7 +650,11 @@ unset(v, c)
 	bslash_quote = 0;
     if (adrof(STRsymlinks) == 0)
 	symlinks = 0;
-    if (did_only && adrof(STRrecognize_only_executables) == 0)
+    if (adrof(STRimplicitcd) == 0)
+	implicit_cd = 0;
+    if (did_edit && noediting && adrof(STRedit) == 0)
+	noediting = 0;
+    if (did_roe && adrof(STRrecognize_only_executables) == 0)
 	tw_cmd_free();
 }
 
@@ -679,7 +694,7 @@ unsetv1(p)
     register struct varent *p;
 {
     register struct varent *c, *pp;
-    register f;
+    register int f;
 
     /*
      * Free associated memory first to avoid complications.
@@ -757,22 +772,29 @@ static void
 exportpath(val)
     Char  **val;
 {
-    Char    exppath[BUFSIZE];
+  Char    	*exppath;
+  size_t	exppath_size = BUFSIZE;
+  exppath = (Char *)xmalloc(sizeof(Char)*exppath_size);
 
     exppath[0] = 0;
     if (val)
 	while (*val) {
-	    if (Strlen(*val) + Strlen(exppath) + 2 > BUFSIZE) {
+	  while (Strlen(*val) + Strlen(exppath) + 2 > exppath_size) {
+	    if ((exppath
+		 = (Char *)xrealloc(exppath, sizeof(Char)*(exppath_size *= 2)))
+		 == NULL) {
 		xprintf(CGETS(18, 1,
 			      "Warning: ridiculously long PATH truncated\n"));
 		break;
+	      }
 	    }
 	    (void) Strcat(exppath, *val++);
 	    if (*val == 0 || eq(*val, STRRparen))
-		break;
+	      break;
 	    (void) Strcat(exppath, STRsep);
-	}
-    tsetenv(STRKPATH, exppath);
+	  }
+  tsetenv(STRKPATH, exppath);
+  free(exppath);
 }
 
 #ifndef lint
@@ -927,7 +949,7 @@ plist(p, what)
     int what;
 {
     register struct varent *c;
-    register len;
+    register int len;
 
     if (setintr)
 #ifdef BSDSIGS
