@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/tc.decls.h,v 3.35 1995/04/29 22:28:24 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.decls.h,v 3.36 1996/04/26 19:20:49 christos Exp $ */
 /*
  * tc.decls.h: Function declarations from all the tcsh modules
  */
@@ -77,9 +77,9 @@ extern	int		  resetdisc	__P((int));
 /*
  * tc.func.c
  */
-extern	Char		 *expand_lex	__P((Char *, int, struct wordent *, 
+extern	Char		 *expand_lex	__P((Char *, size_t, struct wordent *, 
 					     int, int));
-extern	Char		 *sprlex	__P((Char *, struct wordent *));
+extern	Char		 *sprlex	__P((Char *, size_t, struct wordent *));
 extern	void		  Itoa		__P((int, Char *));
 extern	void		  dolist	__P((Char **, struct command *));
 extern	void		  dotelltc	__P((Char **, struct command *));
@@ -142,6 +142,11 @@ extern	void 		  dodmmode	__P((Char **, struct command *));
 extern	void		  douniverse	__P((Char **, struct command *));
 #endif /* masscomp */
 
+#if defined(hcx)
+extern	void		  doatt		__P((Char **, struct command *));
+extern	void		  doucb		__P((Char **, struct command *));
+#endif /* hcx */
+
 #ifdef _SEQUENT_
 extern	void	 	  pr_stat_sub	__P((struct process_stats *, 
 					     struct process_stats *, 
