@@ -1,4 +1,4 @@
-/* $Header: /u/christos/src/tcsh-6.06/RCS/tc.os.h,v 3.63 1995/04/16 19:15:53 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.os.h,v 3.66 1996/10/05 17:39:17 christos Exp $ */
 /*
  * tc.os.h: Shell os dependent defines
  */
@@ -60,6 +60,11 @@
 # include <limits.h>
 #endif /* atp vmsposix */
 
+#ifdef DECOSF1
+# include <sys/signal.h>
+# include <sys/ioctl.h>
+#endif /* DECOSF1 */
+
 #if defined(OPEN_MAX) && !defined(NOFILE)
 # define NOFILE OPEN_MAX
 #endif /* OPEN_MAX && !NOFILE */
@@ -76,7 +81,7 @@
 # undef NEEDstrerror
 #endif /* linux || __NetBSD__ || __FreeBSD__ || SYSVREL >= 4 */
 
-#ifndef pyr
+#if !defined(pyr) && !defined(sinix)
 /* Pyramid's cpp complains about the next line */
 # if defined(BSD) && BSD >= 199306
 #  undef NEEDstrerror
@@ -96,17 +101,25 @@
 #endif /* OREO */
 
 #ifndef NCARGS
-# ifdef ARG_MAX
-#  define NCARGS ARG_MAX
-# else /* !ARG_MAX */
-#  ifdef _MINIX
-#   define NCARGS 80
-#  else /* !_MINIX */
-#   define NCARGS 1024
-#  endif /* _MINIX */
-# endif /* ARG_MAX */
+# ifdef _SC_ARG_MAX
+#  define NCARGS sysconf(_SC_ARG_MAX)
+# else /* !_SC_ARG_MAX */
+#  ifdef ARG_MAX
+#   define NCARGS ARG_MAX
+#  else /* !ARG_MAX */
+#   ifdef _MINIX
+#    define NCARGS 80
+#   else /* !_MINIX */
+#    define NCARGS 1024
+#   endif /* _MINIX */
+#  endif /* ARG_MAX */
+# endif /* _SC_ARG_MAX */
 #endif /* NCARGS */
 
+#ifdef convex
+# include <sys/dmon.h>
+#endif /* convex */
+
 #ifdef titan
 extern int end;
 #endif /* titan */
@@ -131,9 +144,12 @@ struct ucred {
 #  define CSUSP 032
 # endif	/* CSUSP */
 
-# ifndef hp9000s500
+# if !defined(hp9000s500) && !(defined(SIGRTMAX) || defined(SIGRTMIN))
+/*
+ * hpux < 7 || hpux >= 10
+ */
 #  include <sys/bsdtty.h>
-# endif /* hp9000s500 */
+# endif /* !hp9000s500 && !(SIGRTMAX || SIGRTMIN) */
 
 # ifndef POSIX
 #  ifdef BSDJOBS
@@ -476,9 +492,14 @@ struct ucred {
 #endif /* POSIX */
 
 
-#if SYSVREL > 0 && !defined(OREO) && !defined(sgi) && !defined(linux)
+#if SYSVREL > 0 && !defined(OREO) && !defined(sgi) && !defined(linux) && !defined(sinix)
 # define NEEDgetwd
-#endif /* SYSVREL > 0 && !OREO && !sgi && !linux */
+#endif /* SYSVREL > 0 && !OREO && !sgi && !linux && !sinix */
+
+#if defined(SOLARIS2) || defined(sinix)
+# undef NEEDgetwd
+# define getwd(a)	getcwd(a, MAXPATHLEN)
+#endif
 
 #ifndef S_IFLNK
 # define lstat stat
@@ -535,7 +556,9 @@ extern void abort();
 extern void qsort();
 #  endif /* hpux */
 # endif	/* SUNOS4 */
+#ifndef _CX_UX
 extern void perror();
+#endif
 
 # ifdef BSDSIGS
 #  if defined(_AIX370) || defined(MACH) || defined(NeXT) || defined(_AIXPS2) || defined(ardent) || defined(SUNOS4) || defined(HPBSD)
@@ -544,7 +567,9 @@ extern int sigpause();
 #  else	/* !(_AIX370 || MACH || NeXT || _AIXPS2 || ardent || SUNOS4 || HPBSD) */
 #   if (!defined(apollo) || !defined(__STDC__)) && !defined(__DGUX__) && !defined(fps500)
 extern sigret_t sigvec();
+#ifndef _CX_UX
 extern void sigpause();
+#endif /* _CX_UX */
 #   endif /* (!apollo || !__STDC__) && !__DGUX__ && !fps500 */
 #  endif /* _AIX370 || MACH || NeXT || _AIXPS2 || ardent || SUNOS4 || HPBSD */
 extern sigmask_t sigblock();
